@@ -1,4 +1,6 @@
 import json
+from urllib.parse import urlparse
+from contextlib import suppress
 from typing import List, Dict, NoReturn, Any, Iterable, Optional
 from pydantic import validate_arguments, BaseModel
 from jsonschema import validate, ValidationError
@@ -9,6 +11,7 @@ import pydantic
 
 logger = getLogger(__name__)
 
+
 class ActionStore:
     """handles kubiya actions and exeution"""
 
@@ -17,11 +20,20 @@ class ActionStore:
     @classmethod
     def register_action_store(cls, action_store: "ActionStore") -> NoReturn:
         cls._instances.append(action_store)
-    
-    def __init__(self, store_name: str, version: str = "testing") -> None:
-        assert store_name != "", "store_name cannot be empty"
+
+    def __init__(self, store_name: str, version: str = "testing", icon_url=None, category=None) -> None:
+        if store_name == "":
+            raise RuntimeError("store_name cannot be empty")
+        try:
+            if icon_url:
+                urlparse(icon_url)
+            self.icon_url = icon_url
+        except ValueError:
+            raise RuntimeError("icon_url must be a valid URL")
+
         self._registered_actions = {}
         self._action_metadata = {}
+        self._pydantic_models = {}
         self._registered_secrets = []
         self._name = store_name
         self._version = version
@@ -75,6 +87,12 @@ class ActionStore:
         return self._registered_secrets
 
     def execute_action(self, action_name: str, input: Optional[Dict]) -> Any:
+        if self._pydantic_models.get(action_name):
+            try:
+                input = self._pydantic_models[action_name](**input)
+            except pydantic.ValidationError as e:
+                return {"error": e.errors()}
+
         assert (
             action_name in self._registered_actions
         ), f"`{action_name}` is not a registered action"
@@ -99,11 +117,10 @@ class ActionStore:
                     first_arg = func.__code__.co_varnames[0]
                     validate(args[0], input_schema)
                 except ValidationError as e:
-                    return {"error": {"argument": first_arg, "field": e.schema.get("title"), "message": e.message, "expected_type" : e.schema.get("type")}}
+                    return {"error": {"argument": first_arg, "field": e.schema.get("title"), "message": e.message, "expected_type": e.schema.get("type")}}
             return func(*args, **kwargs)
         return wrapper
 
-    
     def kubiya_action(self, validate_input=False) -> callable:
         """dict(type for typy in inspect...)"""
         def decorator(func: callable):
@@ -130,6 +147,9 @@ class ActionStore:
                 model = parameters[0]
                 input_schema = self.annotation_to_schema(
                     model.annotation, model.name)
+                # check if pydantic model
+                if type(model.annotation) == pydantic.main.ModelMetaclass:
+                    self._pydantic_models[func.__name__] = model.annotation
             action_data["input_schema"] = input_schema
             action_data["output_schema"] = output_schema
             self._action_metadata[func.__name__] = action_data
@@ -137,14 +157,14 @@ class ActionStore:
                 self.register_action(func.__name__, func)
             else:
                 if action_data.get("input_schema"):
-                    wrapped = self.validate_args(func, input_schema=input_schema)
+                    wrapped = self.validate_args(
+                        func, input_schema=input_schema)
                     self.register_action(func.__name__, wrapped)
                     return wrapped
             self.register_action(func.__name__, func)
             return func
         return decorator
 
-
     @staticmethod
     def annotation_to_schema(annotation: Any, title: str) -> str:
         if type(annotation) == pydantic.main.ModelMetaclass:
