@@ -1,7 +1,7 @@
-from operator import le
 from sys import exit
 from pathlib import Path
 import importlib.util
+from . import action_store 
 
 def load_action_store_file(file_path: str) -> str:
     file = Path(file_path).absolute()
@@ -19,10 +19,20 @@ def load_action_store_file(file_path: str) -> str:
         print(f"Error loading actions store file: {e}")
         exit(1)
 
-
 def load_action_store(store_name: str) -> str:
     try:
         return load_action_store_file(store_name)
     except Exception as e:
         print(f"Error loading store {store_name}: ({e})")
         exit(1)
+
+def get_all_action_stores(filename=None):
+    return action_store.ActionStore._instances
+
+def get_single_action_store():
+    action_stores = get_all_action_stores()
+    if len(action_stores) == 0:
+        raise AssertionError("No action stores found")
+    if len(action_stores) > 1:
+        raise AssertionError(f"Multiple action stores found: {action_stores}")
+    return action_stores[0]
\ No newline at end of file
