@@ -2,7 +2,7 @@ from kubiya import action_store
 from kubiya.loader import load_action_store
 from sys import argv, exit
 
-def serve_all():
+def show_all():
     instances = action_store.ActionStore._instances
     if not instances:
         print("No action stores found")
@@ -21,4 +21,4 @@ if __name__ == "__main__":
         exit(1)
     
     load_action_store(argv[1])
-    serve_all()
+    show_all()
